@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2010 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -65,9 +65,6 @@ public class ValueWriterSwitch implements WidgetSwitcher {
     }
 
     public Object password(Object... args) {
-        if(null != args[0]) {
-            return "xxxxxxxx";
-        }
         return null;
     }
 
